==> fantacalciobazar_0.2.1.tar.gz: fantacalciobazar/vendi_subito.php <==
<?php

################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
################################################################################

include("controlla_pass.php");
if ($pass_errata != "SI") {



$lock = fopen("mercato.lock","w+");
flock($lock,2);

$trovato = "NO";
$calciatori = file("mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$proprietario = $dati_calciatore[4];

if ($proprietario == $nome_utente) {
if ($num_calciatore == $numero) {
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$costo = $dati_calciatore[3];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off+$aspetta_ore,$minuto_off+$aspetta_minuti,0,$mese_off,$giorno_off+$aspetta_giorni,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$trovato = "SI";
$posizione = $num1;
} # fine if ($sec_restanti < 0)
} # fine if ($num_calciatore == $numero)
} # fine if ($proprietario == $nome_utente)
} # fine for $num1

if ($trovato == "NO") {
echo "<html>
<header>
<title> Fantacalcio </title>
</header>
<body bgcolor=#ffffff>
Non puoi vendere questo calciatore.<br>";
} # fine if ($trovato == "NO")

else {
$prezzo_vendita = floor(($costo/100)*$percentuale_vendita);
$aggiungi_surplus = $prezzo_vendita - $costo; 

$file_mercato = fopen("mercato.txt","w+");
flock($file_mercato,2);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
if ($posizione != $num1) {
fwrite($file_mercato,$calciatori[$num1]);
} # fine if ($posizione != $num1)
} # fine for $num1
flock($file_mercato,3);
fclose($file_mercato);

$lockutente = fopen("squadra_$nome_utente.lock","w+");
flock($lockutente,2);
$linee = @file("squadra_$nome_utente");
$filesquadra = fopen("squadra_$nome_utente","w+");
flock($filesquadra,2);
$num_linee = count($linee);
if ($num_linee < 1) { $num_linee = 1; }
$nuovo_surplus = $linee[0] + $aggiungi_surplus;
$linee[0] = "$nuovo_surplus
";
rewind($filesquadra);
for ($num1 = 0 ; $num1 < $num_linee ; $num1++) {
fwrite($filesquadra,$linee[$num1]);
} # fine for $num1
flock($filesquadra,3);
flock($lockutente,3);

$nuovo_messaggio = "$nome_utente ha venduto $nome per $prezzo_vendita Euro";
$file_messaggi = fopen("messaggi.txt","a+");
flock($file_messaggi,2);
fwrite($file_messaggi,"Radio mercato#@?".$nuovo_messaggio."
");
flock($file_messaggi,3);
fclose($file_messaggi);

echo "<html>
<header>
<title> fantacalcio </title>
<meta http-equiv=\"refresh\" content=\"1; url=squadra.php?nome_squadra=$nome_utente&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">
</header>
<body bgcolor=#ffffff>
Calciatore venduto!<br>";
} # fine else if ($trovato == "NO")

echo "<center><form method=\"post\" action=\"squadra.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
<input type=\"submit\" name=\"torna_squadra\" value=\"Torna alla squadra\">
</form></center>";

flock($lock,3);

} # fine if ($pass_errata != "SI")
?>


</body>
</html>

==> fantacalciobazar_0.3.tar.gz: fantacalciobazar/vendi_subito.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

include("controlla_pass.php");
if ($pass_errata != "SI") {



$lock = fopen("dati/mercato.lock","w+");
flock($lock,2);

$trovato = "NO";
$calciatori = file("dati/mercato.txt");
$num_calciatori = count($calciatori);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
$dati_calciatore = explode(",", $calciatori[$num1]);
$numero = $dati_calciatore[0];
$proprietario = $dati_calciatore[4];

if ($proprietario == $nome_utente) {
if ($num_calciatore == $numero) {
$nome = $dati_calciatore[1];
$ruolo = $dati_calciatore[2];
$costo = $dati_calciatore[3];
$tempo_off = $dati_calciatore[5];
$anno_off = substr($tempo_off,0,4);
$mese_off = substr($tempo_off,4,2);
$giorno_off = substr($tempo_off,6,2);
$ora_off = substr($tempo_off,8,2);
$minuto_off = substr($tempo_off,10,2);
$adesso = mktime(date("H"),date("i"),0,date("m"),date("d"),date("Y"));
$sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
if ($sec_restanti < 0) {
$trovato = "SI";
$posizione = $num1;
} # fine if ($sec_restanti < 0)
} # fine if ($num_calciatore == $numero)
} # fine if ($proprietario == $nome_utente)
} # fine for $num1

if ($trovato == "NO") {
echo "<html>
<header>
<title> Fantacalcio </title>
</header>
<body bgcolor=#ffffff>
Non puoi vendere questo calciatore.<br>";
} # fine if ($trovato == "NO")

else {
$prezzo_vendita = floor(($costo/100)*$percentuale_vendita);
$aggiungi_surplus = $prezzo_vendita - $costo; 

$file_mercato = fopen("dati/mercato.txt","w+");
flock($file_mercato,2);
for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {
if ($posizione != $num1) {
fwrite($file_mercato,$calciatori[$num1]);
} # fine if ($posizione != $num1)
} # fine for $num1
flock($file_mercato,3);
fclose($file_mercato);

$lockutente = fopen("dati/squadra_$nome_utente.lock","w+");
flock($lockutente,2);
$linee = @file("dati/squadra_$nome_utente");
$filesquadra = fopen("dati/squadra_$nome_utente","w+");
flock($filesquadra,2);
$num_linee = count($linee);
if ($num_linee < 1) { $num_linee = 1; }
$nuovo_surplus = $linee[0] + $aggiungi_surplus;
$linee[0] = "$nuovo_surplus
";
rewind($filesquadra);
for ($num1 = 0 ; $num1 < $num_linee ; $num1++) {
fwrite($filesquadra,$linee[$num1]);
} # fine for $num1
flock($filesquadra,3);
flock($lockutente,3);

$nuovo_messaggio = "$nome_utente ha venduto $nome per $prezzo_vendita Euro";
$file_messaggi = fopen("dati/messaggi.txt","a+");
flock($file_messaggi,2);
fwrite($file_messaggi,"Radio mercato#@?".$nuovo_messaggio."
");
flock($file_messaggi,3);
fclose($file_messaggi);

echo "<html>
<header>
<title> fantacalcio </title>
<meta http-equiv=\"refresh\" content=\"1; url=squadra.php?nome_squadra=$nome_utente&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">
</header>
<body bgcolor=#ffffff>
Calciatore venduto!<br>";
} # fine else if ($trovato == "NO")

echo "<center><form method=\"post\" action=\"squadra.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
<input type=\"submit\" name=\"torna_squadra\" value=\"Torna alla squadra\">
</form></center>";

flock($lock,3);

} # fine if ($pass_errata != "SI")
?>


</body>
</html>
